pub struct RemoveCaptcha(pub String);Expand description
Message to delete [Counter] actor
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for RemoveCaptcha
impl Clone for RemoveCaptcha
Sourcefn clone(&self) -> RemoveCaptcha
fn clone(&self) -> RemoveCaptcha
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoveCaptcha
impl Debug for RemoveCaptcha
Sourceimpl<'de> Deserialize<'de> for RemoveCaptcha
impl<'de> Deserialize<'de> for RemoveCaptcha
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Handler<RemoveCaptcha> for Master
impl Handler<RemoveCaptcha> for Master
Sourcetype Result = MessageResult<RemoveCaptcha>
type Result = MessageResult<RemoveCaptcha>
The type of value that this handler will return. Read more
Sourcefn handle(&mut self, m: RemoveCaptcha, ctx: &mut Self::Context) -> Self::Result
fn handle(&mut self, m: RemoveCaptcha, ctx: &mut Self::Context) -> Self::Result
This method is called for every message received by this actor.
Sourceimpl Handler<RemoveCaptcha> for Master
impl Handler<RemoveCaptcha> for Master
Sourcetype Result = MessageResult<RemoveCaptcha>
type Result = MessageResult<RemoveCaptcha>
The type of value that this handler will return. Read more
Sourcefn handle(&mut self, m: RemoveCaptcha, ctx: &mut Self::Context) -> Self::Result
fn handle(&mut self, m: RemoveCaptcha, ctx: &mut Self::Context) -> Self::Result
This method is called for every message received by this actor.
Sourceimpl Message for RemoveCaptcha
impl Message for RemoveCaptcha