pub struct SetInternalData {
pub mcaptcha: HashMap<String, MCaptcha>,
}Expand description
Sets internal Captcha data
Fields
mcaptcha: HashMap<String, MCaptcha>Trait Implementations
Sourceimpl Handler<SetInternalData> for Master
impl Handler<SetInternalData> for Master
Sourcetype Result = MessageResult<SetInternalData>
type Result = MessageResult<SetInternalData>
The type of value that this handler will return. Read more
Sourcefn handle(
&mut self,
m: SetInternalData,
ctx: &mut Self::Context,
) -> Self::Result
fn handle( &mut self, m: SetInternalData, ctx: &mut Self::Context, ) -> Self::Result
This method is called for every message received by this actor.
Sourceimpl Handler<SetInternalData> for Master
impl Handler<SetInternalData> for Master
Sourcetype Result = MessageResult<SetInternalData>
type Result = MessageResult<SetInternalData>
The type of value that this handler will return. Read more
Sourcefn handle(
&mut self,
m: SetInternalData,
ctx: &mut Self::Context,
) -> Self::Result
fn handle( &mut self, m: SetInternalData, ctx: &mut Self::Context, ) -> Self::Result
This method is called for every message received by this actor.
Sourceimpl Message for SetInternalData
impl Message for SetInternalData